@@ -6,6 +6,7 @@ use std::io::Read;
 
 // WIP: OpenAPI support
 pub struct OpenAPI {
+    #[allow(dead_code)]
     opts: HashMap<String, String>,
 }
 
@@ -60,8 +61,7 @@ impl OpenAPI {
                         examples: None,
                     })
                 })
-                .filter(|x| x.is_some())
-                .map(|x| x.unwrap())
+                .flatten()
                 .collect::<Vec<_>>(),
             Err(_e) => vec![], // XXX not used
         };
