@@ -40,12 +40,9 @@ impl ConsoleOutput {
         ConsoleOutput::new_with_buffer(buf, config.contains_key("verbose"))
     }
     pub fn new_with_buffer(buffer: String, verbose: bool) -> ConsoleOutput {
-        ConsoleOutput {
-            buffer: buffer,
-            verbose,
-        }
+        ConsoleOutput { buffer, verbose }
     }
-    fn print_diff_short(&self, benchdiffs: &Vec<Violation>) -> String {
+    fn _print_diff_short(&self, benchdiffs: &[Violation]) -> String {
         let mut out = "".to_string();
         benchdiffs.iter().for_each(|b| {
             out.push_str(
@@ -69,7 +66,7 @@ impl ConsoleOutput {
         });
         out
     }
-    fn print_diff(&self, filter: &str, matchdiffs: &[Violation]) -> String {
+    fn _print_diff(&self, filter: &str, matchdiffs: &[Violation]) -> String {
         let mut out = "".to_string();
 
         let diffs = matchdiffs
@@ -97,8 +94,10 @@ impl ConsoleOutput {
                     )
                     .as_str(),
                 );
-                let (_, _, diff) =
-                    diff_text(&m.recorded, &m.wire.clone().unwrap_or("".to_string()));
+                let (_, _, diff) = diff_text(
+                    &m.recorded,
+                    &m.wire.clone().unwrap_or_else(|| "".to_string()),
+                );
                 out.push_str(format!("      diff: {}\n", diff).as_str());
             })
         }
@@ -121,9 +120,9 @@ impl ConsoleOutput {
 impl ReporterOutput for ConsoleOutput {
     fn start(&mut self, interaction: &Interaction) {
         self.buffer.clear();
-        write!(
+        writeln!(
             self.buffer,
-            "• {}: {}\n",
+            "• {}: {}",
             interaction.request.get_id(),
             style("started").magenta()
         )
@@ -133,10 +132,10 @@ impl ReporterOutput for ConsoleOutput {
     }
     fn report(&mut self, interaction: &Interaction, check_results: &CheckResult) {
         self.buffer.clear();
-        if check_results.violations.len() > 0 {
-            write!(
+        if !check_results.violations.is_empty() {
+            writeln!(
                 self.buffer,
-                "{} {}: {} {}\n",
+                "{} {}: {} {}",
                 style(FAIL_SIGN).red(),
                 interaction.request.get_id(),
                 style("failed").red(),
@@ -145,26 +144,28 @@ impl ReporterOutput for ConsoleOutput {
             .unwrap();
             if self.verbose {
                 check_results.violations.iter().for_each(|v| {
-                    let (_, _, diff) =
-                        diff_text(&v.recorded, &v.wire.clone().unwrap_or("".to_string()));
-                    write!(self.buffer, "      {}: {}\n", v.subject, diff).unwrap();
+                    let (_, _, diff) = diff_text(
+                        &v.recorded,
+                        &v.wire.clone().unwrap_or_else(|| "".to_string()),
+                    );
+                    writeln!(self.buffer, "      {}: {}", v.subject, diff).unwrap();
                 })
             }
         } else if check_results.error.is_some() {
-            write!(
+            writeln!(
                 self.buffer,
-                "{} {}: {} {}\n",
+                "{} {}: {} {}",
                 style(FAIL_SIGN).red(),
                 interaction.request.get_id(),
                 style("error").red(),
                 style(format!("{}ms", check_results.duration.unwrap().as_millis())).dim(),
             )
             .unwrap();
-            write!(self.buffer, "{}\n", check_results.error.clone().unwrap()).unwrap();
+            writeln!(self.buffer, "{}", check_results.error.clone().unwrap()).unwrap();
         } else {
-            write!(
+            writeln!(
                 self.buffer,
-                "{} {}: {} {}\n",
+                "{} {}: {} {}",
                 style(SUCCESS_SIGN).green(),
                 interaction.request.get_id(),
                 style("ok").green(),
@@ -179,13 +180,13 @@ impl ReporterOutput for ConsoleOutput {
 
     fn end(&mut self, interactions: &[Interaction], results: &[CheckResult]) {
         self.buffer.clear();
-        if interactions.len() == 0 {
-            write!(self.buffer, "No interactions found\n").unwrap();
+        if interactions.is_empty() {
+            writeln!(self.buffer, "No interactions found").unwrap();
         } else {
             let duration = results
                 .iter()
                 .map(|c| c.duration)
-                .flat_map(|d| d)
+                .flatten()
                 .reduce(|d, acc| d + acc);
             write!(
                 self.buffer,
@@ -205,7 +206,7 @@ impl ReporterOutput for ConsoleOutput {
                             .iter()
                             .filter(|c| c.error.is_none()
                                 && c.response.is_some()
-                                && c.violations.len() == 0)
+                                && c.violations.is_empty())
                             .count()
                     )
                     .green(),
@@ -214,7 +215,7 @@ impl ReporterOutput for ConsoleOutput {
                             .iter()
                             .filter(|c| c.error.is_none()
                                 && c.response.is_some()
-                                && c.violations.len() > 0)
+                                && !c.violations.is_empty())
                             .count()
                     )
                     .red(),
@@ -293,6 +294,6 @@ mod tests {
         );
 
         o.end(&vec![inter], &vec![fake_result]);
-        assert_eq!(o.buffer.to_string(), "Ran \u{1b}[33m1\u{1b}[0m interactions with \u{1b}[33m1\u{1b}[0m checks in \u{1b}[33m2000ms\u{1b}[0m. Success: \u{1b}[32m0\u{1b}[0m Failure: \u{1b}[31m0\u{1b}[0m Error: \u{1b}[31m0\u{1b}[0m Skipped: \u{1b}[2m1\u{1b}[0m\n");
+        assert_eq!(o.buffer.to_string(), "\nRan \u{1b}[33m1\u{1b}[0m interactions with \u{1b}[33m1\u{1b}[0m checks in \u{1b}[33m2000ms\u{1b}[0m\n\nSuccess: \u{1b}[32m0\u{1b}[0m\nFailure: \u{1b}[31m0\u{1b}[0m\n  Error: \u{1b}[31m0\u{1b}[0m\nSkipped: \u{1b}[2m1\u{1b}[0m\n");
     }
 }
